#!/bin/bash
#Automatically Created by buildpkg 1.7.0
#Maintainer: Pedro Pinto (pnboy~AT~pinguix.com)
#url: http://www.mozilla.org/projects/security/pki/nss/

######Begin Redundant Code######################################
check_for_root() {
	if [ "$UID" != "0" ]; then
		echo "You need to be root"
		exit 1
	fi
}

clean_dirs () {
        for COMPLETED in src pkg; do
                if [ -e $COMPLETED ]; then
                        rm -rf $COMPLETED
                fi
        done
}

clean_old_builds () {
	for COMPLETED in $package.{txz,tgz,md5,dep}; do
		if [ "$KEEPDEPFILE" = "1" ] && [ $COMPLETED = $package.dep ]; then
			continue
		elif [ -e $COMPLETED ]; then
			rm -rf $COMPLETED
		fi
	done
	clean_dirs
}

set_pre_permissions() {
	cd $startdir/src
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;
}


check_for_menu_compliance() {
	if [ -d "$startdir/pkg/usr/share/applications" ]; then
		cd $startdir/pkg/usr/share/applications
		for desktop in *.desktop; do
			Icon=$(grep -e "^Icon=" $desktop | sed 's/Icon=//')
			if [[ "$Icon" ]]; then
				if [ ! "$Icon" == "${Icon%.*}" ]; then
					sed '/Icon/s/\..*$//' -i $desktop
					Icon=$(grep -e "^Icon=" $desktop | sed 's/Icon=//')
				fi
				if [ -d "$startdir/pkg/usr/share/pixmaps" ]; then
					cd $startdir/pkg/usr/share/pixmaps
					for pixmaps in *; do
						[ -d $pixmaps ] && continue
						[ ! "${pixmaps##*.}" == "png" -a ! "${pixmaps##*.}" == "svg" ] && continue
				 		if [ "${pixmaps%.*}" == "$Icon" ]; then
				 			DIR=$(file $pixmaps | awk -F, '{print $2}' | sed 's/ //g')
							[ o"$DIR" == "o" ] && DIR="scalable"
							mkdir -p $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							mv $pixmaps $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							if [[ ! "$(ls $startdir/pkg/usr/share/pixmaps)" ]]; then
								rm -rf $startdir/pkg/usr/share/pixmaps
							fi
						fi
					done
				fi
				if [ -d "$startdir/pkg/usr/share/icons" ]; then
					cd $startdir/pkg/usr/share/icons
					for icons in *; do
				 		if [ "${icons%.*}" == "$Icon" ]; then
							[ ! "${pixmaps##*.}" == "png" -a ! "${pixmaps##*.}" == "svg" ] && continue
				 			DIR=$(file $icons | awk -F, '{print $2}' | sed 's/ //g')
							[ o"$DIR" == "o" ] && DIR="scalable"
							mkdir -p $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
							mv $icons $startdir/pkg/usr/share/icons/hicolor/$DIR/apps
						fi
					done
				fi
			fi
		done
	fi
}


gzip_man_and_info_pages() {
	for DOCS in man info; do
		if [ -d "$startdir/pkg/usr/share/$DOCS" ]; then
			mv $startdir/pkg/usr/share/$DOCS $startdir/pkg/usr/$DOCS
			if [[ ! "$(ls $startdir/pkg/usr/share)" ]]; then
				rm -rf $startdir/pkg/usr/share
			fi
		fi
		if [ -d "$startdir/pkg/usr/$DOCS" ]; then
			# I've never seen symlinks in info pages....
			if [ "$DOCS" == "man" ]; then
				(cd $startdir/pkg/usr/$DOCS
				for manpagedir in $(find . -type d -name "man*" 2> /dev/null) ; do
					( cd $manpagedir
					for eachpage in $( find . -type l -maxdepth 1 2> /dev/null) ; do
						ln -s $( readlink $eachpage ).gz $eachpage.gz
						rm $eachpage
					done )
				done)
			fi
			find $startdir/pkg/usr/$DOCS -type f -exec gzip -9 '{}' \;
		fi
	done
}

set_post_permissions() {
	for DIRS in usr/share/icons usr/doc; do
		if [ -d "$startdir/pkg/$DIRS" ]; then
			if [ "$DIRS" == "usr/doc" ]; then
				find $startdir/pkg/$DIRS -type f -exec chmod 644 {} \;
				find $startdir/pkg/$DIRS -type d -exec chmod 755 {} \;
			fi
		fi
		[ -d $startdir/pkg/$DIRS ] && chown root:root -R $startdir/pkg/$DIRS
	done
	[ -d $startdir/pkg/usr/bin ] && find $startdir/pkg/usr/bin -user root -group bin -exec chown root:root {} \;
}

copy_build_script() {
	mkdir -p $startdir/pkg/usr/src/$pkgname-$pkgver/
	cp $startdir/build-$pkgname.sh $startdir/pkg/usr/src/$pkgname-$pkgver/build-$pkgname.sh
	[ -f $startdir/ZENBUILD ] && cp $startdir/ZENBUILD $startdir/pkg/usr/src/$pkgname-$pkgver/ZENBUILD
}

create_package() {
	ls -lR $startdir/pkg
	cd $startdir/pkg
	/sbin/makepkg -l y -c n $startdir/$package.$PKGEXTENSION
	cd $startdir
	md5sum $package.$PKGEXTENSION > $startdir/$package.md5
}

strip_binaries() {
	cd $startdir/pkg
	find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
	find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
}
#########End Redundant Code#####################################
#########Begin Non Redundant Code##############################

prepare_directory() {
	mkdir $startdir/src
	mkdir -p $startdir/pkg/usr/src/$pkgname-$pkgver
	for SOURCES in ${source[@]}; do
		protocol=$(echo $SOURCES | sed 's|:.*||')
	        file=$(basename $SOURCES | awk -F= '{print $NF}')
		if [ ! -f "$file" ]; then
			if [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
				echo -e "\nDownloading $(basename $SOURCES)\n"
        	                wget $SOURCES -O $file
				if [ ! "$?" == "0" ]; then
					echo "Download failed"
					exit 2
				fi 
			else
				echo "$SOURCES does not appear to be a url nor is it in the directory"
				exit 2
			fi
		fi
		cp -R $file $startdir/src
		if ! [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
			cp -R $startdir/$(basename $SOURCES) $startdir/pkg/usr/src/$pkgname-$pkgver/
		fi
		if [ "${SOURCES##*.}" == "desktop" ]; then
			[[ "$(grep -e "^Categories=[a-zA-Z]*;" $(basename $SOURCES))" ]] && install -D $startdir/$(basename $SOURCES) /home/packages/nss-nspr/pkg/usr/share/applications/$(basename $SOURCES)
		fi
	done
}

extract_source() {
	cd $startdir/src
	if [[ "$(ls $startdir/src)" ]]; then	
		for FILES in ${source[@]}; do
	        	FILES="$(basename $FILES | awk -F= '{print $NF}')"
			file_type=$(file -biz "$FILES")
			unset cmd
			case "$file_type" in
				*application/x-tar*)
					cmd="tar -xf" ;;
				*application/zip*)
					cmd="unzip" ;;
				*application/x-zip*)
					cmd="unzip" ;;
				*application/x-gzip*)
					cmd="gunzip -d -f" ;;
				*application/x-bzip*)
					cmd="bunzip2 -f" ;;
			esac
			if [ "$cmd" != "" ]; then
				echo "$cmd $FILES"
	        	        $cmd $FILES
			fi
		done
	elif [ ! "$source" ]; then
		echo -n "" # lame fix
	else
		echo "no files in the src directory $startdir/src"
		exit 2
	fi
}

build() {
	cd $startdir/src/nss-$pkgver
	export WORKINGDIR=$PWD
	export BUILD_OPT=1
	cd mozilla/security/nss
	sed -i -e "s|NSPR_CONFIGURE_OPTS += --disable-debug --enable-optimize|NSPR_CONFIGURE_OPTS += --disable-debug --enable-optimize=\"${CFLAGS}\"|g" Makefile
	make nss_build_all || return 1
	cd ../..
	export NSS_LINUXDIR=$(basename `ls -d $WORKINGDIR/mozilla/dist/Linux*`)
	mkdir -p $startdir/pkg/usr/{bin,lib/pkgconfig,include/{nss,nspr}}
#	install -v -m755 security/nss/cmd/config/nss-config $startdir/pkg/usr/bin || return 1
	install -v -m755 nsprpub/$NSS_LINUXDIR/config/nspr-config $startdir/pkg/usr/bin || return 1
	NSPR_LIBS=$(./nsprpub/$NSS_LINUXDIR/config/nspr-config --libs)
	NSPR_CFLAGS=$(./nsprpub/$NSS_LINUXDIR/config/nspr-config --cflags)
	NSPR_VERSION=$(./nsprpub/$NSS_LINUXDIR/config/nspr-config --version)

	sed $startdir/src/nspr.pc.in \
		-e "s,%libdir%,/usr/lib," \
		-e "s,%prefix%,/usr," \
		-e "s,%exec_prefix%,/usr/bin," \
		-e "s,%includedir%,/usr/include/nspr," \
		-e "s,%NSPR_VERSION%,${NSPR_VERSION}," \
		-e "s,%FULL_NSPR_LIBS%,${NSPR_LIBS}," \
		-e "s,%FULL_NSPR_CFLAGS%,${NSPR_CFLAGS}," > \
		$startdir/pkg/usr/lib/pkgconfig/nspr.pc  || return 1

	NSS_VMAJOR=$(grep "#define.*NSS_VMAJOR" $startdir/src/nss-$pkgver-with-nspr-${_nsprver}/mozilla/security/nss/lib/nss/nss.h | awk '{print $3}')
	NSS_VMINOR=$(grep "#define.*NSS_VMINOR" $startdir/src/nss-$pkgver-with-nspr-${_nsprver}/mozilla/security/nss/lib/nss/nss.h | awk '{print $3}')
	NSS_VPATCH=$(grep "#define.*NSS_VPATCH" $startdir/src/nss-$pkgver-with-nspr-${_nsprver}/mozilla/security/nss/lib/nss/nss.h | awk '{print $3}')

	sed $startdir/src/nss.pc.in \
		-e "s,%libdir%,/usr/lib,g" \
		-e "s,%prefix%,/usr,g" \
		-e "s,%exec_prefix%,/usr/bin,g" \
		-e "s,%includedir%,/usr/include/nss,g" \
		-e "s,%NSPR_VERSION%,${NSPR_VERSION},g" \
		-e "s,%NSS_VERSION%,${pkgver},g" >  $startdir/pkg/usr/lib/pkgconfig/nss.pc  || return 1

	sed $startdir/src/nss-config.in -e "s,@libdir@,/usr/lib,g" \
                -e "s,@prefix@,/usr/bin,g" \
                -e "s,@exec_prefix@,/usr/bin,g" \
                -e "s,@includedir@,/usr/include/nss,g" \
                -e "s,@MOD_MAJOR_VERSION@,${NSS_VMAJOR},g" \
                -e "s,@MOD_MINOR_VERSION@,${NSS_VMINOR},g" \
                -e "s,@MOD_PATCH_VERSION@,${NSS_VPATCH},g" > $startdir/pkg/usr/bin/nss-config || return 1

	chmod 755 $startdir/pkg/usr/bin/nss-config || return 1


	sed -i -e "s|/local||g" $startdir/pkg/usr/lib/pkgconfig/nss.pc $startdir/pkg/usr/lib/pkgconfig/nspr.pc  || return 1
	sed -i -e "s|/local||g" $startdir/pkg/usr/bin/nspr-config  || return 1
	cd dist
	install -v -m755 $NSS_LINUXDIR/lib/*.so $startdir/pkg/usr/lib  || return 1
	install -v -m755 $NSS_LINUXDIR/lib/{*.chk,libcrmf.a} $startdir/pkg/usr/lib  || return 1
	install -v -m644 {public,private}/nss/* $startdir/pkg/usr/include/nss  || return 1
	cp -v -RL $NSS_LINUXDIR/include/* $startdir/pkg/usr/include/nspr || return 1
	chmod -v 644 $startdir/pkg/usr/include/nspr/prvrsion.h
	( cd $startdir/src/nss-$pkgver-with-nspr-${_nsprver}/mozilla/dist/*.OBJ/bin || return 1
	for bin in certutil modutil pk12util signtool ssltap; do
		find . -type f -iname "$bin" -exec install -v -m755 {} $startdir/pkg/usr/bin \;
	done )
        # build a nss-nspr-devel package
        package2=$pkgname-devel-$pkgver-noarch-$zenver.$pkgrel
        [ -d $startdir/pkg2 ] && rm -rf $startdir/pkg2
        mkdir -p $startdir/pkg2/usr/lib
        mv $startdir/pkg/usr/include $startdir/pkg2/usr/
	mv $startdir/pkg/usr/lib/pkgconfig $startdir/pkg2/usr/lib
	( cd $startdir/pkg2/usr/lib/pkgconfig ; ln -s nspr.pc mozilla-nspr.pc)
	( cd $startdir/pkg2/usr/lib/pkgconfig ; ln -s nss.pc mozilla-nss.pc)
        cd $startdir/pkg2
        mkdir -p $startdir/pkg2/install/
        cat << EOF > $startdir/pkg2/install/slack-desc
$pkgname-devel: $pkgname-devel (NSS & NSPR development package)
$pkgname-devel:
$pkgname-devel: Development files for Network Security Services (NSS) &
$pkgname-devel: Netscape Portable Runtime (NSPR).
EOF
        /sbin/makepkg -l y -c n $startdir/$package2.txz  || return 1
        cd $startdir
        md5sum $package2.txz > $startdir/$package2.md5
        #empty dep file
        echo "">$startdir/$package2.dep
        rm -rvf $startdir/pkg2
        unset package2
} 

create_slackdesc() {
mkdir $startdir/pkg/install
cat <<"EODESC" >$startdir/pkg/install/slack-desc
nss-nspr: Network Security Services (NSS) & Netscape Portable Runtime (NSPR)
nss-nspr: 
nss-nspr: Network Security Services (NSS) is a set of libraries designed to
nss-nspr: support cross-platform development of security-enabled client and
nss-nspr: server applications. Applications built with NSS can support SSL v2
nss-nspr: and v3, TLS, PKCS #5, PKCS #7, PKCS #11, PKCS #12, S/MIME, X.509 v3
nss-nspr: certificates, and other security standards. This package includes
nss-nspr: Netscape Portable Runtime (NSPR) which provides a platform-neutral
nss-nspr: API for system level and libc like functions.
nss-nspr: 
nss-nspr: 
EODESC
}

detect_dependencies() {
	echo "Detecting dependencies..."
	depends=$(requiredbuilder -z $startdir/$package.$PKGEXTENSION)
	
	depstring=$depends
	unset FIRST
	for deps in $(echo "${depstring}" | sed 's/,/\n/g' | sort -u); do
		if [[ ! "$FIRST" ]]; then
			finaldeps=$deps,
			FIRST='1'
			continue
		fi
		finaldeps=${finaldeps}${deps},
	done
	echo "$finaldeps" | sed -e 's/^,//' -e 's/,$//' > $startdir/$package.dep
}
create_source_file(){
	[ -f $package.src ] && rm $package.src
	if [ ! -z $sourcetemplate ]; then
		echo $sourcetemplate/ZENBUILD >> $package.src
		echo $sourcetemplate/build-$pkgname.sh >> $package.src
	else
		echo ZENBUILD >> $package.src
		echo build-$pkgname.sh >> $package.src
	fi
	for SOURCES in ${source[@]}; do
		protocol=$(echo $SOURCES | sed 's|:.*||')
		if ! [ "$protocol" = "http" -o "$protocol" = "https" -o "$protocol" = "ftp" ]; then
			if [ ! -z $sourcetemplate ]; then
				echo $sourcetemplate/$(basename $SOURCES) >> $package.src
			else
				echo $(basename $SOURCES) >> $package.src
			fi
		else
			echo $SOURCES >> $package.src
		fi
	done
}
post_checks(){
	# Ideas taken from src2pkg :)
	if [ -d "$startdir/pkg/usr/doc/$pkgname-$pkgver" ]; then
		for DIRS in usr/doc/$pkgname-$pkgver usr/doc; do
			cd $startdir/pkg/$DIRS
			if [[ $(find . -type f) = "" ]] ; then
				cd ..
				rmdir $DIRS
			fi
		done
	fi
	# if the docs weren't deleted ...
	if [ -d "$startdir/pkg/usr/doc/$pkgname-$pkgver" ]; then
		cd $startdir/pkg/usr/doc/$pkgname-$pkgver
		#remove zero lenght files
		if [[ $(find . -type f -size 0) ]]; then
			echo "Removing some zero lenght files"
			find . -type f -size 0 -exec rm -f {} \;
		fi
	fi
	# check if we need to add code to handle info pages
	if [[ -d $startdir/pkg/usr/info ]] && [[ ! $(grep install-info $startdir/pkg/install/doinst.sh &> /dev/null) ]] ; then
		echo "Found info files - Adding install-info command to doinst.sh"
		INFO_LIST=$(ls -1 $startdir/pkg/usr/info)
		echo "" >> $startdir/pkg/install/doinst.sh
		echo "if [ -x usr/bin/install-info ] ; then" >> $startdir/pkg/install/doinst.sh
		for page in $(echo $INFO_LIST) ; do
			echo " usr/bin/install-info --info-dir=usr/info usr/info/$page 2>/dev/null" >> $startdir/pkg/install/doinst.sh
		done
		echo "fi" >> $startdir/pkg/install/doinst.sh
	fi
	[[ -e $startdir/pkg/usr/info/dir ]] && rm -f $startdir/pkg/usr/info/dir

	if [ -d $startdir/pkg/etc ]; then
		cd $startdir/pkg/
		for conf in $(find ./etc -type f) ; do
			conf=${conf: 2}
			dotnew=( "${dotnew[@]}" "$conf" )
		done
	fi
	if [[ "$dotnew" ]]; then
        for files in ${dotnew[@]} ; do
                fullfile="${startdir}/pkg/${files}"
                if [ -e "$fullfile" ]; then
                        mv $fullfile ${fullfile}.new
                else
                        echo "$fullfile was not found"
                        exit 2
                fi
        done
        cat<<"EODOTNEW" >>$startdir/pkg/install/doinst.sh
#Added by buildpkg 1.7.0
dotnew() {
        NEW="${1}.new"
        OLD="$1"
        if [ ! -e $OLD ]; then
                mv $NEW $OLD
        elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
                rm $NEW
        fi
}
EODOTNEW
for i in ${dotnew[@]}; do
echo "dotnew $i" >> $startdir/pkg/install/doinst.sh
done
fi
}

PKGEXTENSION=txz

####End Non Redundant Code############################

#Variables

startdir=$(pwd)
SRC=$startdir/src
PKG=$startdir/pkg

pkgname=nss-nspr
pkgver=3.12.6
pkgrel=5
zenver=64
arch=i486
package=$pkgname-$pkgver-$arch-$zenver.$pkgrel
_nsprver=4.8.4
source=("http://ftp.mozilla.org/pub/mozilla.org/security/nss/releases/NSS_3_12_6_RTM/src/nss-3.12.6-with-nspr-4.8.4.tar.gz" "http://pnboy.pinguix.com/my_packages/zenwalk/nss-nspr/3.12.6/nss.pc.in" "http://pnboy.pinguix.com/my_packages/zenwalk/nss-nspr/3.12.6/nspr.pc.in" "http://pnboy.pinguix.com/my_packages/zenwalk/nss-nspr/3.12.6/nss-config.in")
sourcetemplate=http://pnboy.pinguix.com/my_packages/zenwalk/nss-nspr/3.12.6
docs=()
export CFLAGS="-O2 -march=i486 -mtune=i686"
export CXXFLAGS="-O2 -march=i486 -mtune=i686"

#Execution

check_for_root
clean_old_builds
prepare_directory
extract_source
set_pre_permissions
build
if [ ! "$?" = "0" ]; then
	echo "build() failed."
	exit 2
fi
create_slackdesc
post_checks
check_for_menu_compliance
strip_binaries
gzip_man_and_info_pages
set_post_permissions
copy_build_script
create_package
create_source_file
detect_dependencies
echo "Package has been built."
echo "Cleaning pkg and src directories"
clean_dirs
